summaryrefslogtreecommitdiff
path: root/examples/ibb_transfer/ibb_sender.py
diff options
context:
space:
mode:
Diffstat (limited to 'examples/ibb_transfer/ibb_sender.py')
-rwxr-xr-xexamples/ibb_transfer/ibb_sender.py144
1 files changed, 62 insertions, 82 deletions
diff --git a/examples/ibb_transfer/ibb_sender.py b/examples/ibb_transfer/ibb_sender.py
index 7c380b68..f1c0cab2 100755
--- a/examples/ibb_transfer/ibb_sender.py
+++ b/examples/ibb_transfer/ibb_sender.py
@@ -1,43 +1,36 @@
-#!/usr/bin/env python
+#!/usr/bin/env python3
# -*- coding: utf-8 -*-
"""
SleekXMPP: The Sleek XMPP Library
Copyright (C) 2010 Nathanael C. Fritz
- This file is part of SleekXMPP.
+ This file is part of Slixmpp.
See the file LICENSE for copying permission.
"""
-import sys
+import asyncio
import logging
-import getpass
-from optparse import OptionParser
+from getpass import getpass
+from argparse import ArgumentParser
-import sleekxmpp
+import slixmpp
+from slixmpp.exceptions import IqError, IqTimeout
-# Python versions before 3.0 do not use UTF-8 encoding
-# by default. To ensure that Unicode is handled properly
-# throughout SleekXMPP, we will set the default encoding
-# ourselves to UTF-8.
-if sys.version_info < (3, 0):
- from sleekxmpp.util.misc_ops import setdefaultencoding
- setdefaultencoding('utf8')
-else:
- raw_input = input
-
-class IBBSender(sleekxmpp.ClientXMPP):
+class IBBSender(slixmpp.ClientXMPP):
"""
A basic example of creating and using an in-band bytestream.
"""
- def __init__(self, jid, password, receiver, filename):
- sleekxmpp.ClientXMPP.__init__(self, jid, password)
+ def __init__(self, jid, password, receiver, filename, use_messages=False):
+ slixmpp.ClientXMPP.__init__(self, jid, password)
self.receiver = receiver
- self.filename = filename
+
+ self.file = open(filename, 'rb')
+ self.use_messages = use_messages
# The session_start event will be triggered when
# the bot establishes its connection with the server
@@ -46,6 +39,7 @@ class IBBSender(sleekxmpp.ClientXMPP):
# our roster.
self.add_event_handler("session_start", self.start)
+ @asyncio.coroutine
def start(self, event):
"""
Process the session_start event.
@@ -62,84 +56,70 @@ class IBBSender(sleekxmpp.ClientXMPP):
self.send_presence()
self.get_roster()
- # For the purpose of demonstration, we'll set a very small block
- # size. The default block size is 4096. We'll also use a window
- # allowing sending multiple blocks at a time; in this case, three
- # block transfers may be in progress at any time.
- stream = self['xep_0047'].open_stream(self.receiver)
+ try:
+ # Open the IBB stream in which to write to.
+ stream = yield from self['xep_0047'].open_stream(self.receiver, use_messages=self.use_messages)
+
+ # If you want to send in-memory bytes, use stream.sendall() instead.
+ yield from stream.sendfile(self.file, timeout=10)
- with open(self.filename) as f:
- data = f.read()
- stream.sendall(data)
+ # And finally close the stream.
+ yield from stream.close(timeout=10)
+ except (IqError, IqTimeout):
+ print('File transfer errored')
+ else:
+ print('File transfer finished')
+ finally:
+ self.file.close()
+ self.disconnect()
if __name__ == '__main__':
# Setup the command line arguments.
- optp = OptionParser()
+ parser = ArgumentParser()
# Output verbosity options.
- optp.add_option('-q', '--quiet', help='set logging to ERROR',
- action='store_const', dest='loglevel',
- const=logging.ERROR, default=logging.INFO)
- optp.add_option('-d', '--debug', help='set logging to DEBUG',
- action='store_const', dest='loglevel',
- const=logging.DEBUG, default=logging.INFO)
- optp.add_option('-v', '--verbose', help='set logging to COMM',
- action='store_const', dest='loglevel',
- const=5, default=logging.INFO)
+ parser.add_argument("-q", "--quiet", help="set logging to ERROR",
+ action="store_const", dest="loglevel",
+ const=logging.ERROR, default=logging.INFO)
+ parser.add_argument("-d", "--debug", help="set logging to DEBUG",
+ action="store_const", dest="loglevel",
+ const=logging.DEBUG, default=logging.INFO)
# JID and password options.
- optp.add_option("-j", "--jid", dest="jid",
- help="JID to use")
- optp.add_option("-p", "--password", dest="password",
- help="password to use")
- optp.add_option("-r", "--receiver", dest="receiver",
- help="JID to use")
- optp.add_option("-f", "--file", dest="filename",
- help="JID to use")
-
- opts, args = optp.parse_args()
+ parser.add_argument("-j", "--jid", dest="jid",
+ help="JID to use")
+ parser.add_argument("-p", "--password", dest="password",
+ help="password to use")
+ parser.add_argument("-r", "--receiver", dest="receiver",
+ help="JID of the receiver")
+ parser.add_argument("-f", "--file", dest="filename",
+ help="file to send")
+ parser.add_argument("-m", "--use-messages", action="store_true",
+ help="use messages instead of iqs for file transfer")
+
+ args = parser.parse_args()
# Setup logging.
- logging.basicConfig(level=opts.loglevel,
+ logging.basicConfig(level=args.loglevel,
format='%(levelname)-8s %(message)s')
- if opts.jid is None:
- opts.jid = raw_input("Username: ")
- if opts.password is None:
- opts.password = getpass.getpass("Password: ")
- if opts.receiver is None:
- opts.receiver = raw_input("Receiver: ")
- if opts.filename is None:
- opts.filename = raw_input("File path: ")
+ if args.jid is None:
+ args.jid = input("Username: ")
+ if args.password is None:
+ args.password = getpass("Password: ")
+ if args.receiver is None:
+ args.receiver = input("Receiver: ")
+ if args.filename is None:
+ args.filename = input("File path: ")
- # Setup the EchoBot and register plugins. Note that while plugins may
+ # Setup the IBBSender and register plugins. Note that while plugins may
# have interdependencies, the order in which you register them does
# not matter.
- xmpp = IBBSender(opts.jid, opts.password, opts.receiver, opts.filename)
+ xmpp = IBBSender(args.jid, args.password, args.receiver, args.filename, args.use_messages)
xmpp.register_plugin('xep_0030') # Service Discovery
- xmpp.register_plugin('xep_0004') # Data Forms
xmpp.register_plugin('xep_0047') # In-band Bytestreams
- xmpp.register_plugin('xep_0060') # PubSub
- xmpp.register_plugin('xep_0199') # XMPP Ping
-
- # If you are working with an OpenFire server, you may need
- # to adjust the SSL version used:
- # xmpp.ssl_version = ssl.PROTOCOL_SSLv3
-
- # If you want to verify the SSL certificates offered by a server:
- # xmpp.ca_certs = "path/to/ca/cert"
# Connect to the XMPP server and start processing XMPP stanzas.
- if xmpp.connect():
- # If you do not have the dnspython library installed, you will need
- # to manually specify the name of the server if it does not match
- # the one in the JID. For example, to use Google Talk you would
- # need to use:
- #
- # if xmpp.connect(('talk.google.com', 5222)):
- # ...
- xmpp.process(block=True)
- print("Done")
- else:
- print("Unable to connect.")
+ xmpp.connect()
+ xmpp.process(forever=False)
@@ -1,43 +1,36 @@
# -*- coding: utf-8 -*-
"""
- SleekXMPP: The Sleek XMPP Library
+ Slixmpp: The Slick XMPP Library
Copyright (C) 2010 Nathanael C. Fritz